@@ -49,9 +49,6 @@
 #include <cmath>
 
 
-#define DEBUG_LAYOUT 0
-
-
 namespace
 {
     const int cardMoveDuration = 230;
@@ -82,9 +79,9 @@ namespace
         if ( KCardPile * pile = qobject_cast<KCardPile*>( object ) )
             return pile;
 
-        Q_ASSERT( object == 0 );
+        Q_ASSERT( !object );
 
-        return 0;
+        return nullptr;
     }
 }
 
@@ -148,7 +145,7 @@ KCardPile * KCardScenePrivate::bestDestinationPileUnderCards()
             targets << p;
     }
 
-    KCardPile * bestTarget = 0;
+    KCardPile * bestTarget = nullptr;
     qreal bestArea = 1;
 
     foreach ( KCardPile * p, targets )
@@ -409,7 +406,7 @@ KCardScene::KCardScene( QObject * parent )
   : QGraphicsScene( parent ),
     d( new KCardScenePrivate( this ) )
 {
-    d->deck = 0;
+    d->deck = nullptr;
     d->alignment = AlignHCenter | AlignHSpread;
     d->layoutMargin = 0.15;
     d->layoutSpacing = 0.15;
@@ -1177,12 +1174,12 @@ void KCardScene::mouseReleaseEvent( QGraphicsSceneMouseEvent * e )
         if ( e->button() == Qt::LeftButton )
         {
             emit pileClicked( pile );
-            emit pile->clicked( 0 );
+            emit pile->clicked( nullptr );
         }
         else if ( e->button() == Qt::RightButton )
         {
             emit pileRightClicked( pile );
-            emit pile->rightClicked( 0 );
+            emit pile->rightClicked( nullptr );
         }
     }
     else
@@ -1216,7 +1213,7 @@ void KCardScene::mouseDoubleClickEvent( QGraphicsSceneMouseEvent * e )
     {
         e->accept();
         emit pileDoubleClicked( pile );
-        emit pile->doubleClicked( 0 );
+        emit pile->doubleClicked( nullptr );
     }
     else
     {
@@ -1249,31 +1246,6 @@ void KCardScene::drawForeground ( QPainter * painter, const QRectF & rect )
 {
     Q_UNUSED( painter )
     Q_UNUSED( rect )
-
-#if DEBUG_LAYOUT
-    if ( !d->sizeHasBeenSet || !d->deck  )
-        return;
-
-    painter->setPen( Qt::yellow );
-    painter->drawRect( 0, 0, d->contentSize.width(), d->contentSize.height() );
-
-    foreach ( const KCardPile * p, piles() )
-    {
-        if ( !p->isVisible() )
-            continue;
-
-        QRectF availableRect = multRectSize( d->pileAreas.value( p, QRectF() ), d->deck->cardSize() );
-
-        QRectF reservedRect( -p->leftPadding(), -p->topPadding(), 1 + p->rightPadding(), 1 + p->bottomPadding() );
-        reservedRect = multRectSize( reservedRect, d->deck->cardSize() );
-        reservedRect.translate( p->pos() );
-
-        painter->setPen( Qt::cyan );
-        painter->drawRect( availableRect );
-        painter->setPen( QPen( Qt::red, 1, Qt::DotLine, Qt::FlatCap ) );
-        painter->drawRect( reservedRect );
-    }
-#endif
 }
 
 
